
library(stringr)
library(quanteda)
library(pdftools)
library(scico)

# ptext <- pdf_text(list.files("./Named Papers/", full.names = TRUE)[1])

read_and_clean <- function(pdfloc){
  ptext <- pdf_text(pdfloc)
  clean.text <- str_replace_all(ptext, pattern = "\n", replacement = " ")
  clean.text <- str_replace_all(clean.text, pattern = "\r", replacement = " ")
  clean.text <- str_replace_all(clean.text, pattern = "\"", replacement = " ")
  clean.text <- paste(clean.text, collapse = " ")
  clean.text <- str_replace_all(paste(clean.text, collapse = " "),
                                pattern = "Page.......", replacement = "")
  return(clean.text)
}

### Direct to folder with "Named Papers" for running text scrapping. Papers used in the analysis are not provided with the code due to licensing 
rawtext <- unlist(lapply(list.files("./Named Papers/", full.names = TRUE), function(x){
  read_and_clean(pdfloc = x)
}))

corpus.text <- corpus(rawtext)
refID <- as.numeric(apply(str_extract_all(str_extract(list.files("./Named Papers/"),
                                                      "^.{3}"), "[:digit:]",
                simplify = TRUE), 1, function(x){paste(x, collapse = "")}))
docvars(corpus.text, field = "refID") <-  refID

dfmat.text <- dfm(corpus.text,
                  remove = stopwords("english"),
                  stem = TRUE, remove_punct = TRUE)

rdata <- read.csv("./Data/ReptileHRReview_LiteratureReview.csv",
                  stringsAsFactors = FALSE, na.strings = c("NA","N/A"), encoding = "UTF-8")

loc.terms <- trimws(str_replace_all(unlist(str_split(rdata$locationTerms, ",|;")), "[:punct:]", " "))
loc.terms <- unique(loc.terms)
loc.terms <- loc.terms[!loc.terms == "" & !is.na(loc.terms)]

loc.tokens <- tokens_wordstem(tokens(loc.terms,
                       "word"))

# manual cleaning
loc.clean <- unique(unlist(loc.tokens))
loc.clean <- loc.clean[!loc.clean %in% c("ob", "re", "uniqu", "use")]
# data point was missed off and converted to data
loc.clean[loc.clean == "data"] <- "datapoint"

length(loc.clean)

trim.dfmat <- dfmat.text[,colnames(dfmat.text) %in% loc.clean]

set.seed(1)

png(filename = "./Figures/Loc Word Cloud.png", width = 120, height = 120, units = "mm",
    res = 300, pointsize = 24)
textplot_wordcloud(trim.dfmat, min_count = 2, random_order = FALSE,
                   rotation = .25,
                   color = scico(20, palette = "roma"))
dev.off()
##
